bread.contrib.reports.fields package
====================================

.. automodule:: bread.contrib.reports.fields
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.contrib.reports.fields.modelfieldlookup module
----------------------------------------------------

.. automodule:: bread.contrib.reports.fields.modelfieldlookup
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.reports.fields.queryfield module
----------------------------------------------

.. automodule:: bread.contrib.reports.fields.queryfield
   :members:
   :undoc-members:
   :show-inheritance:
